Class: Google::Cloud::Support::V2beta::CreateSupportEventSubscriptionRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/support/v2beta/support_event_subscription_service.rb

Overview

Request message for CreateSupportEventSubscription.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The parent resource name where the support event subscription will be created. Format: organizations/{organization_id}.

Returns:

  • (::String)

    Required. The parent resource name where the support event subscription will be created. Format: organizations/{organization_id}



32
33
34
35
# File 'proto_docs/google/cloud/support/v2beta/support_event_subscription_service.rb', line 32

class CreateSupportEventSubscriptionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#support_event_subscription::Google::Cloud::Support::V2beta::SupportEventSubscription

Returns Required. The Pub/Sub configuration to create.

Returns:



32
33
34
35
# File 'proto_docs/google/cloud/support/v2beta/support_event_subscription_service.rb', line 32

class CreateSupportEventSubscriptionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end