Class: Google::Cloud::Support::V2beta::SearchCasesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/support/v2beta/case_service.rb

Overview

The response message for the SearchCases endpoint.

Instance Attribute Summary collapse

Instance Attribute Details

#cases::Array<::Google::Cloud::Support::V2beta::Case>

Returns The list of cases associated with the parent after any filters have been applied.

Returns:



162
163
164
165
# File 'proto_docs/google/cloud/support/v2beta/case_service.rb', line 162

class SearchCasesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token to retrieve the next page of results. Set this in the page_token field of subsequent cases.search requests. If unspecified, there are no more results to retrieve.

Returns:

  • (::String)

    A token to retrieve the next page of results. Set this in the page_token field of subsequent cases.search requests. If unspecified, there are no more results to retrieve.



162
163
164
165
# File 'proto_docs/google/cloud/support/v2beta/case_service.rb', line 162

class SearchCasesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end