Class: Google::Cloud::Support::V2beta::SupportEventSubscription

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/support/v2beta/support_event_subscription.rb

Overview

A support event subscription.

Defined Under Namespace

Modules: FailureReason, State

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which the subscription was created.

Returns:



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'proto_docs/google/cloud/support/v2beta/support_event_subscription.rb', line 51

class SupportEventSubscription
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the subscription.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Subscription is active and working.
    WORKING = 1

    # Subscription is failing. Notifications cannot be published for some
    # reason.
    FAILING = 2

    # Subscription has been deleted and is pending purge. Notifications are not
    # sent for deleted subscriptions. Deleted subscriptions are purged after
    # their `purge_time` has passed.
    DELETED = 3
  end

  # The reason why the subscription is failing.
  module FailureReason
    # Unspecified failure reason.
    FAILURE_REASON_UNSPECIFIED = 0

    # The service account (i.e.
    # cloud-support-apievents@system.gserviceaccount.com) lacks the permission
    # to publish to the customer's Pub/Sub topic.
    PERMISSION_DENIED = 1

    # The specified Pub/Sub topic does not exist.
    TOPIC_NOT_FOUND = 2

    # Message failed to publish due to a system-side error.
    OTHER = 3
  end
end

#delete_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which the subscription was deleted.

Returns:



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'proto_docs/google/cloud/support/v2beta/support_event_subscription.rb', line 51

class SupportEventSubscription
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the subscription.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Subscription is active and working.
    WORKING = 1

    # Subscription is failing. Notifications cannot be published for some
    # reason.
    FAILING = 2

    # Subscription has been deleted and is pending purge. Notifications are not
    # sent for deleted subscriptions. Deleted subscriptions are purged after
    # their `purge_time` has passed.
    DELETED = 3
  end

  # The reason why the subscription is failing.
  module FailureReason
    # Unspecified failure reason.
    FAILURE_REASON_UNSPECIFIED = 0

    # The service account (i.e.
    # cloud-support-apievents@system.gserviceaccount.com) lacks the permission
    # to publish to the customer's Pub/Sub topic.
    PERMISSION_DENIED = 1

    # The specified Pub/Sub topic does not exist.
    TOPIC_NOT_FOUND = 2

    # Message failed to publish due to a system-side error.
    OTHER = 3
  end
end

#failure_reason::Google::Cloud::Support::V2beta::SupportEventSubscription::FailureReason (readonly)

Returns Output only. Reason why subscription is failing. State of subscription must be FAILING in order for this to have a value.

Returns:



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'proto_docs/google/cloud/support/v2beta/support_event_subscription.rb', line 51

class SupportEventSubscription
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the subscription.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Subscription is active and working.
    WORKING = 1

    # Subscription is failing. Notifications cannot be published for some
    # reason.
    FAILING = 2

    # Subscription has been deleted and is pending purge. Notifications are not
    # sent for deleted subscriptions. Deleted subscriptions are purged after
    # their `purge_time` has passed.
    DELETED = 3
  end

  # The reason why the subscription is failing.
  module FailureReason
    # Unspecified failure reason.
    FAILURE_REASON_UNSPECIFIED = 0

    # The service account (i.e.
    # cloud-support-apievents@system.gserviceaccount.com) lacks the permission
    # to publish to the customer's Pub/Sub topic.
    PERMISSION_DENIED = 1

    # The specified Pub/Sub topic does not exist.
    TOPIC_NOT_FOUND = 2

    # Message failed to publish due to a system-side error.
    OTHER = 3
  end
end

#name::String

Returns Identifier. The resource name of the support event subscription.

Returns:

  • (::String)

    Identifier. The resource name of the support event subscription.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'proto_docs/google/cloud/support/v2beta/support_event_subscription.rb', line 51

class SupportEventSubscription
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the subscription.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Subscription is active and working.
    WORKING = 1

    # Subscription is failing. Notifications cannot be published for some
    # reason.
    FAILING = 2

    # Subscription has been deleted and is pending purge. Notifications are not
    # sent for deleted subscriptions. Deleted subscriptions are purged after
    # their `purge_time` has passed.
    DELETED = 3
  end

  # The reason why the subscription is failing.
  module FailureReason
    # Unspecified failure reason.
    FAILURE_REASON_UNSPECIFIED = 0

    # The service account (i.e.
    # cloud-support-apievents@system.gserviceaccount.com) lacks the permission
    # to publish to the customer's Pub/Sub topic.
    PERMISSION_DENIED = 1

    # The specified Pub/Sub topic does not exist.
    TOPIC_NOT_FOUND = 2

    # Message failed to publish due to a system-side error.
    OTHER = 3
  end
end

#pub_sub_topic::String

Returns Required. The name of the Pub/Sub topic to publish notifications to. Format: projects/{project}/topics/{topic}.

Returns:

  • (::String)

    Required. The name of the Pub/Sub topic to publish notifications to. Format: projects/{project}/topics/{topic}



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'proto_docs/google/cloud/support/v2beta/support_event_subscription.rb', line 51

class SupportEventSubscription
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the subscription.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Subscription is active and working.
    WORKING = 1

    # Subscription is failing. Notifications cannot be published for some
    # reason.
    FAILING = 2

    # Subscription has been deleted and is pending purge. Notifications are not
    # sent for deleted subscriptions. Deleted subscriptions are purged after
    # their `purge_time` has passed.
    DELETED = 3
  end

  # The reason why the subscription is failing.
  module FailureReason
    # Unspecified failure reason.
    FAILURE_REASON_UNSPECIFIED = 0

    # The service account (i.e.
    # cloud-support-apievents@system.gserviceaccount.com) lacks the permission
    # to publish to the customer's Pub/Sub topic.
    PERMISSION_DENIED = 1

    # The specified Pub/Sub topic does not exist.
    TOPIC_NOT_FOUND = 2

    # Message failed to publish due to a system-side error.
    OTHER = 3
  end
end

#purge_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which the subscription will be purged.

Returns:



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'proto_docs/google/cloud/support/v2beta/support_event_subscription.rb', line 51

class SupportEventSubscription
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the subscription.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Subscription is active and working.
    WORKING = 1

    # Subscription is failing. Notifications cannot be published for some
    # reason.
    FAILING = 2

    # Subscription has been deleted and is pending purge. Notifications are not
    # sent for deleted subscriptions. Deleted subscriptions are purged after
    # their `purge_time` has passed.
    DELETED = 3
  end

  # The reason why the subscription is failing.
  module FailureReason
    # Unspecified failure reason.
    FAILURE_REASON_UNSPECIFIED = 0

    # The service account (i.e.
    # cloud-support-apievents@system.gserviceaccount.com) lacks the permission
    # to publish to the customer's Pub/Sub topic.
    PERMISSION_DENIED = 1

    # The specified Pub/Sub topic does not exist.
    TOPIC_NOT_FOUND = 2

    # Message failed to publish due to a system-side error.
    OTHER = 3
  end
end

#state::Google::Cloud::Support::V2beta::SupportEventSubscription::State (readonly)

Returns Output only. The state of the subscription.

Returns:



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'proto_docs/google/cloud/support/v2beta/support_event_subscription.rb', line 51

class SupportEventSubscription
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the subscription.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Subscription is active and working.
    WORKING = 1

    # Subscription is failing. Notifications cannot be published for some
    # reason.
    FAILING = 2

    # Subscription has been deleted and is pending purge. Notifications are not
    # sent for deleted subscriptions. Deleted subscriptions are purged after
    # their `purge_time` has passed.
    DELETED = 3
  end

  # The reason why the subscription is failing.
  module FailureReason
    # Unspecified failure reason.
    FAILURE_REASON_UNSPECIFIED = 0

    # The service account (i.e.
    # cloud-support-apievents@system.gserviceaccount.com) lacks the permission
    # to publish to the customer's Pub/Sub topic.
    PERMISSION_DENIED = 1

    # The specified Pub/Sub topic does not exist.
    TOPIC_NOT_FOUND = 2

    # Message failed to publish due to a system-side error.
    OTHER = 3
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which the subscription was last updated.

Returns:



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'proto_docs/google/cloud/support/v2beta/support_event_subscription.rb', line 51

class SupportEventSubscription
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the subscription.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Subscription is active and working.
    WORKING = 1

    # Subscription is failing. Notifications cannot be published for some
    # reason.
    FAILING = 2

    # Subscription has been deleted and is pending purge. Notifications are not
    # sent for deleted subscriptions. Deleted subscriptions are purged after
    # their `purge_time` has passed.
    DELETED = 3
  end

  # The reason why the subscription is failing.
  module FailureReason
    # Unspecified failure reason.
    FAILURE_REASON_UNSPECIFIED = 0

    # The service account (i.e.
    # cloud-support-apievents@system.gserviceaccount.com) lacks the permission
    # to publish to the customer's Pub/Sub topic.
    PERMISSION_DENIED = 1

    # The specified Pub/Sub topic does not exist.
    TOPIC_NOT_FOUND = 2

    # Message failed to publish due to a system-side error.
    OTHER = 3
  end
end