Class: Google::Cloud::Support::V2beta::ListSupportEventSubscriptionsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Support::V2beta::ListSupportEventSubscriptionsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/support/v2beta/support_event_subscription_service.rb
Overview
Request message for ListSupportEventSubscriptions.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
-
#show_deleted ⇒ ::Boolean
Optional.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. Filter expression based on AIP-160. Supported fields:
- pub_sub_topic
- state
Examples:
pub_sub_topic="projects/example-project/topics/example-topic"state=WORKINGpub_sub_topic="projects/example-project/topics/example-topic" AND state=WORKING.
80 81 82 83 |
# File 'proto_docs/google/cloud/support/v2beta/support_event_subscription_service.rb', line 80 class ListSupportEventSubscriptionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. The maximum number of support event subscriptions to return.
80 81 82 83 |
# File 'proto_docs/google/cloud/support/v2beta/support_event_subscription_service.rb', line 80 class ListSupportEventSubscriptionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A token identifying the page of results to return. If unspecified, the first page is retrieved.
When paginating, all other parameters provided to
ListSupportEventSubscriptions must match the call that provided the page
token.
80 81 82 83 |
# File 'proto_docs/google/cloud/support/v2beta/support_event_subscription_service.rb', line 80 class ListSupportEventSubscriptionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The fully qualified name of the Cloud resource to list support event subscriptions under. Format: organizations/{organization_id}.
80 81 82 83 |
# File 'proto_docs/google/cloud/support/v2beta/support_event_subscription_service.rb', line 80 class ListSupportEventSubscriptionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#show_deleted ⇒ ::Boolean
Returns Optional. Whether to show deleted subscriptions. By default, deleted subscriptions are not returned.
80 81 82 83 |
# File 'proto_docs/google/cloud/support/v2beta/support_event_subscription_service.rb', line 80 class ListSupportEventSubscriptionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |