Class: Google::Cloud::Support::V2beta::SupportEventSubscriptionService::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Support::V2beta::SupportEventSubscriptionService::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/support/v2beta/support_event_subscription_service/rest/client.rb
Overview
REST client for the SupportEventSubscriptionService service.
Service for managing customer support event subscriptions.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the SupportEventSubscriptionService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the SupportEventSubscriptionService Client instance.
-
#create_support_event_subscription(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Support::V2beta::SupportEventSubscription
Creates a support event subscription for an organization.
-
#delete_support_event_subscription(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Support::V2beta::SupportEventSubscription
Soft deletes a support event subscription.
-
#get_support_event_subscription(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Support::V2beta::SupportEventSubscription
Gets a support event subscription.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new SupportEventSubscriptionService REST client object.
-
#list_support_event_subscriptions(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Support::V2beta::SupportEventSubscription>
Lists support event subscriptions.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#undelete_support_event_subscription(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Support::V2beta::SupportEventSubscription
Undeletes a support event subscription.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_support_event_subscription(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Support::V2beta::SupportEventSubscription
Updates a support event subscription.
Methods included from Paths
#organization_path, #support_event_subscription_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new SupportEventSubscriptionService REST client object.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/google/cloud/support/v2beta/support_event_subscription_service/rest/client.rb', line 126 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @support_event_subscription_service_stub = ::Google::Cloud::Support::V2beta::SupportEventSubscriptionService::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @support_event_subscription_service_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the SupportEventSubscriptionService Client class.
See Configuration for a description of the configuration fields.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/google/cloud/support/v2beta/support_event_subscription_service/rest/client.rb', line 64 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Support", "V2beta"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the SupportEventSubscriptionService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
96 97 98 99 |
# File 'lib/google/cloud/support/v2beta/support_event_subscription_service/rest/client.rb', line 96 def configure yield @config if block_given? @config end |
#create_support_event_subscription(request, options = nil) ⇒ ::Google::Cloud::Support::V2beta::SupportEventSubscription #create_support_event_subscription(parent: nil, support_event_subscription: nil) ⇒ ::Google::Cloud::Support::V2beta::SupportEventSubscription
Creates a support event subscription for an organization.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/google/cloud/support/v2beta/support_event_subscription_service/rest/client.rb', line 225 def create_support_event_subscription request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Support::V2beta::CreateSupportEventSubscriptionRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_support_event_subscription..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Support::V2beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_support_event_subscription.timeout, metadata: , retry_policy: @config.rpcs.create_support_event_subscription.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @support_event_subscription_service_stub.create_support_event_subscription request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_support_event_subscription(request, options = nil) ⇒ ::Google::Cloud::Support::V2beta::SupportEventSubscription #delete_support_event_subscription(name: nil) ⇒ ::Google::Cloud::Support::V2beta::SupportEventSubscription
Soft deletes a support event subscription.
575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 |
# File 'lib/google/cloud/support/v2beta/support_event_subscription_service/rest/client.rb', line 575 def delete_support_event_subscription request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Support::V2beta::DeleteSupportEventSubscriptionRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_support_event_subscription..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Support::V2beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.delete_support_event_subscription.timeout, metadata: , retry_policy: @config.rpcs.delete_support_event_subscription.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @support_event_subscription_service_stub.delete_support_event_subscription request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_support_event_subscription(request, options = nil) ⇒ ::Google::Cloud::Support::V2beta::SupportEventSubscription #get_support_event_subscription(name: nil) ⇒ ::Google::Cloud::Support::V2beta::SupportEventSubscription
Gets a support event subscription.
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/google/cloud/support/v2beta/support_event_subscription_service/rest/client.rb', line 305 def get_support_event_subscription request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Support::V2beta::GetSupportEventSubscriptionRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_support_event_subscription..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Support::V2beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_support_event_subscription.timeout, metadata: , retry_policy: @config.rpcs.get_support_event_subscription.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @support_event_subscription_service_stub.get_support_event_subscription request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_support_event_subscriptions(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Support::V2beta::SupportEventSubscription> #list_support_event_subscriptions(parent: nil, filter: nil, show_deleted: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Support::V2beta::SupportEventSubscription>
Lists support event subscriptions.
411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 |
# File 'lib/google/cloud/support/v2beta/support_event_subscription_service/rest/client.rb', line 411 def list_support_event_subscriptions request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Support::V2beta::ListSupportEventSubscriptionsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_support_event_subscriptions..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Support::V2beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_support_event_subscriptions.timeout, metadata: , retry_policy: @config.rpcs.list_support_event_subscriptions.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @support_event_subscription_service_stub.list_support_event_subscriptions request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @support_event_subscription_service_stub, :list_support_event_subscriptions, "support_event_subscriptions", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
173 174 175 |
# File 'lib/google/cloud/support/v2beta/support_event_subscription_service/rest/client.rb', line 173 def logger @support_event_subscription_service_stub.logger end |
#undelete_support_event_subscription(request, options = nil) ⇒ ::Google::Cloud::Support::V2beta::SupportEventSubscription #undelete_support_event_subscription(name: nil) ⇒ ::Google::Cloud::Support::V2beta::SupportEventSubscription
Undeletes a support event subscription.
655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 |
# File 'lib/google/cloud/support/v2beta/support_event_subscription_service/rest/client.rb', line 655 def undelete_support_event_subscription request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Support::V2beta::UndeleteSupportEventSubscriptionRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.undelete_support_event_subscription..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Support::V2beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.undelete_support_event_subscription.timeout, metadata: , retry_policy: @config.rpcs.undelete_support_event_subscription.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @support_event_subscription_service_stub.undelete_support_event_subscription request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
106 107 108 |
# File 'lib/google/cloud/support/v2beta/support_event_subscription_service/rest/client.rb', line 106 def universe_domain @support_event_subscription_service_stub.universe_domain end |
#update_support_event_subscription(request, options = nil) ⇒ ::Google::Cloud::Support::V2beta::SupportEventSubscription #update_support_event_subscription(support_event_subscription: nil, update_mask: nil) ⇒ ::Google::Cloud::Support::V2beta::SupportEventSubscription
Updates a support event subscription.
495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 |
# File 'lib/google/cloud/support/v2beta/support_event_subscription_service/rest/client.rb', line 495 def update_support_event_subscription request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Support::V2beta::UpdateSupportEventSubscriptionRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_support_event_subscription..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Support::V2beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_support_event_subscription.timeout, metadata: , retry_policy: @config.rpcs.update_support_event_subscription.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @support_event_subscription_service_stub.update_support_event_subscription request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |